log_density_blow: Calculate the log of the proposal density for the Blow kernel

View source: R/twalk_engine.R

log_density_blowR Documentation

Calculate the log of the proposal density for the Blow kernel

Description

Calculate the log of the proposal density for the Blow kernel

Usage

log_density_blow(n_phi, phi, h, x, xp)

Arguments

n_phi

Number of moved coordinates.

phi

Boolean vector indicating moved coordinates.

h

Proposed point.

x

Reference point.

xp

Reference point.

Value

The value of -log(g(h)).


Rtwalk documentation built on Feb. 5, 2026, 5:07 p.m.