twalk_move: Run a single t-walk move (step)

View source: R/twalk_engine.R

twalk_moveR Documentation

Run a single t-walk move (step)

Description

Selects one of the four kernels, generates a proposal, and calculates the Metropolis-Hastings acceptance probability.

Usage

twalk_move(
  n_dim,
  log_post_fun,
  support_fun,
  x,
  U,
  xp,
  Up,
  at = 6,
  aw = 1.5,
  p_phi = min(n_dim, 4)/n_dim,
  p_traverse = 0.4918,
  p_walk = 0.4918,
  p_blow = 0.0082,
  ...
)

Arguments

...

Arguments passed to 'log_post_fun' and 'support_fun'.

Value

A list containing the proposal and the acceptance probability.


Rtwalk documentation built on Feb. 5, 2026, 5:07 p.m.