| twalk_move | R Documentation |
Selects one of the four kernels, generates a proposal, and calculates the Metropolis-Hastings acceptance probability.
twalk_move(
n_dim,
log_post_fun,
support_fun,
x,
U,
xp,
Up,
at = 6,
aw = 1.5,
p_phi = min(n_dim, 4)/n_dim,
p_traverse = 0.4918,
p_walk = 0.4918,
p_blow = 0.0082,
...
)
... |
Arguments passed to 'log_post_fun' and 'support_fun'. |
A list containing the proposal and the acceptance probability.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.